@@ -63,7 +63,7 @@ from .background_tasks import TASKS_TO_SPAWN
 
 from .misc import (
     cache_community_types,
-    create_product_and_set,
+    create_product_and_set
 )
 
 from .key_loader import KeyLoader
@@ -71,7 +71,7 @@ from .key_loader import KeyLoader
 from .constants import MAP_IMAGES, COMMUNITY_TYPES
 
 
-__version__ = "0.1.0"
+__version__ = "0.1.1"
 __url__ = "https://github.com/WardPearce/SQLMatches"
 __description__ = "SQLMatches, match & demos recorder."
 __author__ = "WardPearce"
@@ -95,7 +95,7 @@ class SQLMatches(Starlette):
                      B2UploadSettings, LocalUploadSettings] = None,
                  map_images: Dict[str, str] = MAP_IMAGES,
                  upload_delay: float = 0.00001,
-                 free_upload_size: float = 50.0,
+                 free_upload_size: float = 30.0,
                  max_upload_size: float = 100.0,
                  cost_per_mb: float = 0.15,
                  timestamp_format: str = "%m/%d/%Y-%H:%M:%S",
